@@ -1,7 +1,12 @@
 #ifndef ABOUT_H
 #define ABOUT_H
 
-static const char about_text[] = {
+#include <libintl.h>
+#ifndef gettext_noop
+#define gettext_noop(String) String
+#endif
+
+static const char * about_text = gettext_noop(
           "Welcome to Tux Paint's graphical configuration tool, created by "
           "Torsten Giebl, Jan Wynholds, Bill Kendrick, and Martin Fuhrer.\n"
           "\n"
@@ -18,6 +23,6 @@ static const char about_text[] = {
           "button at the bottom to write out a new configuration file.\n"
           "\n"
           "The next time Tux Paint is launched, the new settings should take "
-          "effect."};
+          "effect.");
 
 #endif /* ABOUT_H */
